import React, { useEffect, useRef, useState } from 'react'
import { Box } from '@mui/material'
import { useTheme, type Theme } from '@mui/material/styles'
import {
  useLocalCameraTrack,
  useLocalMicrophoneTrack,
  useRemoteUsers,
  usePublish,
} from 'agora-rtc-react'
import SymmetricGrid from '../SymmetricGrid/SymmetricGrid'

const MeetingLayout = () => {
  const theme: Theme = useTheme()

  const { localCameraTrack } = useLocalCameraTrack()
  const { localMicrophoneTrack } = useLocalMicrophoneTrack()
  usePublish([localMicrophoneTrack, localCameraTrack])
  const remoteUsers = useRemoteUsers()

  const gridContainerRef = useRef<HTMLDivElement>(null)
  const [gridContainerHeight, setGridContainerHeight] = useState(0)

  const [totalUsers, setTotalUsers] = useState(20)

  useEffect(() => {
    setTotalUsers(remoteUsers.length + 1)
  }, [remoteUsers])

  useEffect(() => {
    if (gridContainerRef.current) {
      setGridContainerHeight(gridContainerRef.current.offsetHeight)
    }
  }, [gridContainerRef?.current?.offsetHeight])

  return (
    <Box
      sx={{
        width: '100%',
        height: '80%',
        backgroundColor: theme.palette.background.default,
        padding: '30px',
        display: 'flex',
        flexDirection: 'column',
      }}
    >
      <Box
        sx={{
          display: 'flex',
          flexDirection: 'row',
          width: '100%',
          height: '100%',
        }}
        ref={gridContainerRef}
      >
        <SymmetricGrid
          totalUsers={totalUsers}
          setTotalUsers={setTotalUsers}
          gridContainerHeight={gridContainerHeight}
          setGridContainerHeight={setGridContainerHeight}
        />
      </Box>
    </Box>
  )
}

export default MeetingLayout
